# arpes.plotting.fit\_inspection\_tool module

**class arpes.plotting.fit\_inspection\_tool.FitCheckTool(**kwargs)\*\*

> Bases:
> [arpes.plotting.interactive\_utils.BokehInteractiveTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.BokehInteractiveTool),
> [arpes.plotting.interactive\_utils.CursorTool](arpes.plotting.interactive_utils#arpes.plotting.interactive_utils.CursorTool)
> 
> Verification of fits
> 
> `auto_rebin = False`
> 
> `auto_zero_nans = False`
> 
> **tool\_handler(doc)**
